"""
passlib wrapper

Defines acceptable cryptstings
"""
from __future__ import print_function

import logging

from passlib.context import CryptContext


logger = logging.getLogger(__name__)
schemes = (
    'sha256_crypt',
    'sha512_crypt',
    'plaintext'
)
context = CryptContext(schemes=schemes)


def hash(passwd, scheme=None):
    return context.hash(passwd, scheme=scheme)


def verify(passwd, cryptstring):
    return context.verify(passwd, cryptstring)


# python -m

def main(inargs=None):
    import argparse
    import getpass
    import sys

    parser = argparse.ArgumentParser(
        description='Make a cryptsting with passlib')
    sub = parser.add_subparsers(title='command', description='command')

    def get_password_loop(verify=False):
        try:
            while True:
                passwd = confirm = getpass.getpass('password: ',
                                                   stream=sys.stderr)
                if verify:
                    confirm = getpass.getpass('confirm password: ',
                                              stream=sys.stderr)
                if passwd != confirm:
                    print('Passwords does not match!', file=sys.stderr)
                else:
                    return passwd
        except EOFError:
            raise SystemExit("EOF, abort!")
        except KeyboardInterrupt:
            raise SystemExit('Interrupt, abort!')

    # make <method>

    def do_hash(args):
        password = get_password_loop(verify=True)
        print(hash(password, scheme=args.scheme))

    sub_make = sub.add_parser('make')
    sub_make.add_argument(
        '--scheme',
        choices=schemes,
        default=None)
    sub_make.set_defaults(action=do_hash)

    # validate <cryptstring>

    def do_verify(args):
        password = get_password_loop(verify=False)
        if verify(password, args.cryptstring):
            print('OK', file=sys.stderr)
        else:
            raise SystemExit('Invalid password')

    sub_make = sub.add_parser('verify')
    sub_make.add_argument('cryptstring')
    sub_make.set_defaults(action=do_verify)

    parser.set_defaults(action=do_hash)
    args = parser.parse_args(inargs)
    args.action(args)


if __name__ == '__main__':
    main()
