#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Mock for the Gatekeeper middleware.
"""
from flask import current_app

from flask_feide_gk import gatekeeper


class MockGatekeeperData(gatekeeper.GatekeeperData):
    """
    Flask middleware component for mocking featching of Gatekeeper request data.

    Does not require any basic authentication.
    """
    def __init__(self, app=None):
        if app is not None:
            self.init_app(app)

    def init_app(self, app):
        pass

    def _get_mock_user(self, user_id=None):
        configured_user = current_app.config.get('FEIDE_MOCK_LOGIN_AS', None)
        user_id = user_id or configured_user
        if not user_id:
            return {}
        data = current_app.config['FEIDE_MOCK_DATA']
        return data['users'].get(user_id)

    @property
    def is_authenticated(self):
        return True

    @property
    def user_id(self):
        return self._get_mock_user().get('id')

    @property
    def client_id(self):
        return current_app.config['FEIDE_MOCK_DATA']['client_id']

    @property
    def user_sec(self):
        return gatekeeper.UserIds(self._get_mock_user().get('sec'))

    @property
    def access_token(self):
        return ''

    def require(self, func):
        # We don't validate the request
        return func
